pub struct RoleSet { /* private fields */ }Expand description
A set of roles participating in a protocol.
Provides convenient operations for working with collections of roles.
Implementations
Sourceimpl RoleSet
impl RoleSet
Sourcepub fn from_roles(iter: impl IntoIterator<Item = Role>) -> Self
pub fn from_roles(iter: impl IntoIterator<Item = Role>) -> Self
Create a role set from an iterator
Note: Consider using collect() directly via the FromIterator implementation.
Sourcepub fn contains_name(&self, name: &str) -> bool
pub fn contains_name(&self, name: &str) -> bool
Check if the set contains a role by name