pub struct ChannelCapacity(/* private fields */);Expand description
Channel capacity (bits).
Implementations
Sourceimpl ChannelCapacity
impl ChannelCapacity
pub const MIN: u32 = 0
pub const MAX: u32 = MAX_CHANNEL_CAPACITY_BITS
Sourcepub fn new(value: u32) -> Result<Self, CountError>
pub fn new(value: u32) -> Result<Self, CountError>
Create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
Sourcepub fn try_new(value: u32) -> Result<Self, CountError>
pub fn try_new(value: u32) -> Result<Self, CountError>
Try to create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
pub const fn new_unchecked(value: u32) -> Self
pub const fn get(self) -> u32
pub const fn as_usize(self) -> usize