pub struct LoopCount(/* private fields */);Expand description
Count of loop iterations (bounded).
Implementations
Sourceimpl LoopCount
impl LoopCount
pub const MIN: u32 = 0
pub const MAX: u32 = MAX_LOOP_COUNT
Sourcepub fn new(value: u32) -> Result<Self, CountError>
pub fn new(value: u32) -> Result<Self, CountError>
Create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
Sourcepub fn try_new(value: u32) -> Result<Self, CountError>
pub fn try_new(value: u32) -> Result<Self, CountError>
Try to create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
pub const fn new_unchecked(value: u32) -> Self
pub const fn get(self) -> u32
pub const fn as_usize(self) -> usize