pub struct QueueCapacity(/* private fields */);Expand description
Queue capacity (entries).
Implementations
Sourceimpl QueueCapacity
impl QueueCapacity
pub const MIN: u32 = 1
pub const MAX: u32 = MAX_QUEUE_CAPACITY_COUNT
Sourcepub fn new(value: u32) -> Result<Self, CountError>
pub fn new(value: u32) -> Result<Self, CountError>
Create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
Sourcepub fn try_new(value: u32) -> Result<Self, CountError>
pub fn try_new(value: u32) -> Result<Self, CountError>
Try to create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
pub const fn new_unchecked(value: u32) -> Self
pub const fn get(self) -> u32
pub const fn as_usize(self) -> usize